@@ -5,7 +5,7 @@ use warnings;
 use feature qw(say state);
 
 package App::GitHubPullRequest;
-$App::GitHubPullRequest::VERSION = '0.5.0';
+$App::GitHubPullRequest::VERSION = '0.6.0';
 # ABSTRACT: Command-line tool to query GitHub pull requests
 
 use JSON qw(decode_json encode_json);
@@ -45,7 +45,8 @@ Where command is one of these:
   checkout <number> Create tracking branch for specified pull request
 
   login [<user>] [<password>] [<two-factor-auth-token>]
-                              Login to GitHub and receive an access token
+                              Login to GitHub and receive an access token (deprecated)
+  authorize                   Create a GitHub OAuth personal access token
   comment <number> [<text>]   Create a comment on the specified pull request
   close <number>              Close the specified pull request
   open <number>               Reopen the specified pull request
@@ -266,6 +267,10 @@ sub comment {
 sub login {
     my ($self, $user, $password, $two_factor_token) = @_;
 
+    # Add deprecation message
+    say "\nThis authorization method is deprecated and will be removed on November 13, 2020.";
+    say "Please use the 'authorize' command to authenticate with GitHub.\n";
+
     # Try to fetch user/password from git config (or prompt)
     $user     ||= _qx('git', "config github.user")     || _prompt('GitHub username');
     $password ||= _qx('git', "config github.password") || _prompt('GitHub password', 'hidden');
@@ -292,7 +297,35 @@ sub login {
     die("Authentication data does not include a token.\n")
         unless $token;
 
-    # Store successful authorization token
+    # Store authorization token
+    my ($content, $rc) = _run_ext(qw(git config --global github.pr-token), $token);
+    die("git config returned message '$content' and code $rc when trying to store your token.\n")
+        if $rc != 0;
+    say "Access token stored successfully. Go to https://github.com/settings/tokens to revoke access.";
+    return 0;
+}
+
+
+sub authorize {
+    my ($self, $token) = @_;
+    # Verify that you want to overwrite an existing token
+    my $old_token = _qx('git', "config github.pr-token");
+    if ( $old_token and not $token ) {
+        say "You're already authorized.";
+        my $q = _prompt("Do you want to generate a new token (y/N)") || "n";
+        return 0 if lc($q) ne 'y';
+    }
+    # Give instructions and ask for token if not specified on command line
+    unless ( $token ) {
+        say "Go to https://github.com/settings/tokens/new and follow the directions to generate a new token.";
+        say "Give the token a name of your choice, e.g. 'git-pr', and give it the 'repo' permission.";
+        say "The 'public_repo' permission is enough if you only plan to use it with public repositories.\n";
+        $token = _prompt('GitHub OAuth personal access token');
+    }
+    # Make sure a token is specified
+    die("No token was specified. No changes have been made to your configuration.\n")
+        unless $token;
+    # Store authorization token
     my ($content, $rc) = _run_ext(qw(git config --global github.pr-token), $token);
     die("git config returned message '$content' and code $rc when trying to store your token.\n")
         if $rc != 0;
@@ -660,7 +693,7 @@ App::GitHubPullRequest - Command-line tool to query GitHub pull requests
 
 =head1 VERSION
 
-version 0.5.0
+version 0.6.0
 
 =head1 SYNOPSIS
 
@@ -671,7 +704,7 @@ version 0.5.0
     $ git pr checkout 7  # create upstream tracking branch pr/7
     $ git pr help
 
-    $ git pr login       # Get access token for commands below
+    $ git pr authorize   # Get access token for commands below
     $ git pr close 7
     $ git pr open 7
     $ git pr comment 7 'This is good stuff!'
@@ -755,10 +788,17 @@ The text must be encoded using UTF-8.
 
 =head2 login [<user>] [<password>] [<2fa-token>]
 
-Logs you in to GitHub and creates a new access token used instead of your
-password and two-factor authentication token.  If you don't specify either
-of the options, they are looked up in your git config github section.  If
-none of those are found, you'll be prompted for them.
+DEPRECATED: Logs you in to GitHub and creates a new access token used
+instead of your password and two-factor authentication token. If you don't
+specify either of the options, they are looked up in your git config github
+section. If none of those are found, you'll be prompted for them.
+
+=head2 authorize [<access-token>]
+
+Logs you in to GitHub by manually creating an OAuth personal access token.
+Follow the directions on-screen to generate one and insert it when prompted.
+If you already have an access token you want to use you can also specify it
+on the command line.
 
 =head1 METHODS
 
@@ -786,9 +826,9 @@ Be aware, that if that repo is a fork, the program will look for its parent.
 
 =head1 CAVEATS
 
-If you don't authenticate with GitHub using the login command, it will use
+If you don't authenticate with GitHub using the authorize command, it will use
 unauthenticated API requests where possible, which has a rate-limit of 60
-requests.  If you login first it should allow 5000 requests before you hit
+requests.  If you authorize first it should allow 5000 requests before you hit
 the limit.
 
 You must be standing in a directory that is a git dir and that directory must
@@ -937,7 +977,7 @@ Robin Smidsrød <robin@smidsrod.no>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Robin Smidsrød.
+This software is copyright (c) 2020 by Robin Smidsrød.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
